==> python3-cyberfusion-cluster-support-1.43.tar.gz: python3-cyberfusion-cluster-support-1.43/src/cyberfusion/ClusterSupport/firewall_groups.py <==
"""Helper classes for scripts for cluster support packages."""

from typing import List

from cyberfusion.ClusterSupport._interfaces import APIObjectInterface

ENDPOINT_FIREWALL_GROUPS = "firewall-groups"
MODEL_FIREWALL_GROUPS = "firewall_groups"


class FirewallGroup(APIObjectInterface):
    """Represents object."""

    _TABLE_HEADERS = [
        "ID",
        "Name",
        "IP Networks",
    ]
    _TABLE_HEADERS_DETAILED = [
        "Cluster",
    ]

    _TABLE_FIELDS = [
        "id",
        "name",
        "ip_networks",
    ]
    _TABLE_FIELDS_DETAILED = [
        "_cluster_name",
    ]

    def _set_attributes_from_model(
        self,
        obj: dict,
    ) -> None:
        """Set class attributes from API output."""
        self.id = obj["id"]
        self.name = obj["name"]
        self.ip_networks = obj["ip_networks"]
        self.cluster_id: int = obj["cluster_id"]
        self.created_at = obj["created_at"]
        self.updated_at = obj["updated_at"]

        self.cluster = self.support.get_clusters(id_=self.cluster_id)[0]

        self._cluster_name = self.cluster.name

    def create(
        self,
        *,
        name: str,
        ip_networks: List[str],
        cluster_id: int,
    ) -> None:
        """Create object."""
        url = f"/api/v1/{ENDPOINT_FIREWALL_GROUPS}"
        data = {
            "name": name,
            "ip_networks": ip_networks,
            "cluster_id": cluster_id,
        }

        self.support.request.POST(url, data)
        response = self.support.request.execute()

        self._set_attributes_from_model(response)

        self.support.firewall_groups.append(self)

    def update(self) -> None:
        """Update object."""
        url = f"/api/v1/{ENDPOINT_FIREWALL_GROUPS}/{self.id}"
        data = {
            "id": self.id,
            "name": self.name,
            "ip_networks": self.ip_networks,
            "cluster_id": self.cluster_id,
        }

        self.support.request.PUT(url, data)
        response = self.support.request.execute()

        self._set_attributes_from_model(response)

    def delete(self) -> None:
        """Delete object."""
        url = f"/api/v1/{ENDPOINT_FIREWALL_GROUPS}/{self.id}"

        self.support.request.DELETE(url)
        self.support.request.execute()

        self.support.firewall_groups.remove(self)

==> python3-cyberfusion-cluster-support-1.44.tar.gz: python3-cyberfusion-cluster-support-1.44/src/cyberfusion/ClusterSupport/firewall_groups.py <==
"""Helper classes for scripts for cluster support packages."""

from typing import List

from cyberfusion.ClusterSupport._interfaces import APIObjectInterface

ENDPOINT_FIREWALL_GROUPS = "firewall-groups"
MODEL_FIREWALL_GROUPS = "firewall_groups"


class FirewallGroup(APIObjectInterface):
    """Represents object."""

    _TABLE_HEADERS = [
        "ID",
        "Name",
        "IP Networks",
        "Cluster",
    ]
    _TABLE_HEADERS_DETAILED: list = []

    _TABLE_FIELDS = [
        "id",
        "name",
        "ip_networks",
        "_cluster_name",
    ]
    _TABLE_FIELDS_DETAILED: list = []

    def _set_attributes_from_model(
        self,
        obj: dict,
    ) -> None:
        """Set class attributes from API output."""
        self.id = obj["id"]
        self.name = obj["name"]
        self.ip_networks = obj["ip_networks"]
        self.cluster_id: int = obj["cluster_id"]
        self.created_at = obj["created_at"]
        self.updated_at = obj["updated_at"]

        self.cluster = self.support.get_clusters(id_=self.cluster_id)[0]

        self._cluster_name = self.cluster.name

    def create(
        self,
        *,
        name: str,
        ip_networks: List[str],
        cluster_id: int,
    ) -> None:
        """Create object."""
        url = f"/api/v1/{ENDPOINT_FIREWALL_GROUPS}"
        data = {
            "name": name,
            "ip_networks": ip_networks,
            "cluster_id": cluster_id,
        }

        self.support.request.POST(url, data)
        response = self.support.request.execute()

        self._set_attributes_from_model(response)

        self.support.firewall_groups.append(self)

    def update(self) -> None:
        """Update object."""
        url = f"/api/v1/{ENDPOINT_FIREWALL_GROUPS}/{self.id}"
        data = {
            "id": self.id,
            "name": self.name,
            "ip_networks": self.ip_networks,
            "cluster_id": self.cluster_id,
        }

        self.support.request.PUT(url, data)
        response = self.support.request.execute()

        self._set_attributes_from_model(response)

    def delete(self) -> None:
        """Delete object."""
        url = f"/api/v1/{ENDPOINT_FIREWALL_GROUPS}/{self.id}"

        self.support.request.DELETE(url)
        self.support.request.execute()

        self.support.firewall_groups.remove(self)
